# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hedgehog/protocol/proto/hedgehog.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hedgehog.protocol.proto import ack_pb2 as hedgehog_dot_protocol_dot_proto_dot_ack__pb2
from hedgehog.protocol.proto import io_pb2 as hedgehog_dot_protocol_dot_proto_dot_io__pb2
from hedgehog.protocol.proto import motor_pb2 as hedgehog_dot_protocol_dot_proto_dot_motor__pb2
from hedgehog.protocol.proto import servo_pb2 as hedgehog_dot_protocol_dot_proto_dot_servo__pb2
from hedgehog.protocol.proto import process_pb2 as hedgehog_dot_protocol_dot_proto_dot_process__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hedgehog/protocol/proto/hedgehog.proto',
  package='hedgehog.protocol.proto',
  syntax='proto3',
  serialized_pb=_b('\n&hedgehog/protocol/proto/hedgehog.proto\x12\x17hedgehog.protocol.proto\x1a!hedgehog/protocol/proto/ack.proto\x1a hedgehog/protocol/proto/io.proto\x1a#hedgehog/protocol/proto/motor.proto\x1a#hedgehog/protocol/proto/servo.proto\x1a%hedgehog/protocol/proto/process.proto\"\xae\t\n\x0fHedgehogMessage\x12\x43\n\x0f\x61\x63knowledgement\x18\x01 \x01(\x0b\x32(.hedgehog.protocol.proto.AcknowledgementH\x00\x12\x36\n\tio_action\x18\x02 \x01(\x0b\x32!.hedgehog.protocol.proto.IOActionH\x00\x12G\n\x12io_command_message\x18\x10 \x01(\x0b\x32).hedgehog.protocol.proto.IOCommandMessageH\x00\x12@\n\x0e\x61nalog_message\x18\x03 \x01(\x0b\x32&.hedgehog.protocol.proto.AnalogMessageH\x00\x12\x42\n\x0f\x64igital_message\x18\x04 \x01(\x0b\x32\'.hedgehog.protocol.proto.DigitalMessageH\x00\x12<\n\x0cmotor_action\x18\x05 \x01(\x0b\x32$.hedgehog.protocol.proto.MotorActionH\x00\x12M\n\x15motor_command_message\x18\x11 \x01(\x0b\x32,.hedgehog.protocol.proto.MotorCommandMessageH\x00\x12I\n\x13motor_state_message\x18\x06 \x01(\x0b\x32*.hedgehog.protocol.proto.MotorStateMessageH\x00\x12T\n\x19motor_set_position_action\x18\x12 \x01(\x0b\x32/.hedgehog.protocol.proto.MotorSetPositionActionH\x00\x12<\n\x0cservo_action\x18\x07 \x01(\x0b\x32$.hedgehog.protocol.proto.ServoActionH\x00\x12M\n\x15servo_command_message\x18\x13 \x01(\x0b\x32,.hedgehog.protocol.proto.ServoCommandMessageH\x00\x12O\n\x16process_execute_action\x18\x14 \x01(\x0b\x32-.hedgehog.protocol.proto.ProcessExecuteActionH\x00\x12M\n\x15process_execute_reply\x18\x15 \x01(\x0b\x32,.hedgehog.protocol.proto.ProcessExecuteReplyH\x00\x12O\n\x16process_stream_message\x18\x08 \x01(\x0b\x32-.hedgehog.protocol.proto.ProcessStreamMessageH\x00\x12M\n\x15process_signal_action\x18\x16 \x01(\x0b\x32,.hedgehog.protocol.proto.ProcessSignalActionH\x00\x12I\n\x13process_exit_update\x18\x17 \x01(\x0b\x32*.hedgehog.protocol.proto.ProcessExitUpdateH\x00\x42\t\n\x07payloadB,\n\x1f\x61t.pria.hedgehog.protocol.protoB\tHedgehogPb\x06proto3')
  ,
  dependencies=[hedgehog_dot_protocol_dot_proto_dot_ack__pb2.DESCRIPTOR,hedgehog_dot_protocol_dot_proto_dot_io__pb2.DESCRIPTOR,hedgehog_dot_protocol_dot_proto_dot_motor__pb2.DESCRIPTOR,hedgehog_dot_protocol_dot_proto_dot_servo__pb2.DESCRIPTOR,hedgehog_dot_protocol_dot_proto_dot_process__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_HEDGEHOGMESSAGE = _descriptor.Descriptor(
  name='HedgehogMessage',
  full_name='hedgehog.protocol.proto.HedgehogMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='acknowledgement', full_name='hedgehog.protocol.proto.HedgehogMessage.acknowledgement', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='io_action', full_name='hedgehog.protocol.proto.HedgehogMessage.io_action', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='io_command_message', full_name='hedgehog.protocol.proto.HedgehogMessage.io_command_message', index=2,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='analog_message', full_name='hedgehog.protocol.proto.HedgehogMessage.analog_message', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='digital_message', full_name='hedgehog.protocol.proto.HedgehogMessage.digital_message', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motor_action', full_name='hedgehog.protocol.proto.HedgehogMessage.motor_action', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motor_command_message', full_name='hedgehog.protocol.proto.HedgehogMessage.motor_command_message', index=6,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motor_state_message', full_name='hedgehog.protocol.proto.HedgehogMessage.motor_state_message', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motor_set_position_action', full_name='hedgehog.protocol.proto.HedgehogMessage.motor_set_position_action', index=8,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='servo_action', full_name='hedgehog.protocol.proto.HedgehogMessage.servo_action', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='servo_command_message', full_name='hedgehog.protocol.proto.HedgehogMessage.servo_command_message', index=10,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_execute_action', full_name='hedgehog.protocol.proto.HedgehogMessage.process_execute_action', index=11,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_execute_reply', full_name='hedgehog.protocol.proto.HedgehogMessage.process_execute_reply', index=12,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_stream_message', full_name='hedgehog.protocol.proto.HedgehogMessage.process_stream_message', index=13,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_signal_action', full_name='hedgehog.protocol.proto.HedgehogMessage.process_signal_action', index=14,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_exit_update', full_name='hedgehog.protocol.proto.HedgehogMessage.process_exit_update', index=15,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='hedgehog.protocol.proto.HedgehogMessage.payload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=250,
  serialized_end=1448,
)

_HEDGEHOGMESSAGE.fields_by_name['acknowledgement'].message_type = hedgehog_dot_protocol_dot_proto_dot_ack__pb2._ACKNOWLEDGEMENT
_HEDGEHOGMESSAGE.fields_by_name['io_action'].message_type = hedgehog_dot_protocol_dot_proto_dot_io__pb2._IOACTION
_HEDGEHOGMESSAGE.fields_by_name['io_command_message'].message_type = hedgehog_dot_protocol_dot_proto_dot_io__pb2._IOCOMMANDMESSAGE
_HEDGEHOGMESSAGE.fields_by_name['analog_message'].message_type = hedgehog_dot_protocol_dot_proto_dot_io__pb2._ANALOGMESSAGE
_HEDGEHOGMESSAGE.fields_by_name['digital_message'].message_type = hedgehog_dot_protocol_dot_proto_dot_io__pb2._DIGITALMESSAGE
_HEDGEHOGMESSAGE.fields_by_name['motor_action'].message_type = hedgehog_dot_protocol_dot_proto_dot_motor__pb2._MOTORACTION
_HEDGEHOGMESSAGE.fields_by_name['motor_command_message'].message_type = hedgehog_dot_protocol_dot_proto_dot_motor__pb2._MOTORCOMMANDMESSAGE
_HEDGEHOGMESSAGE.fields_by_name['motor_state_message'].message_type = hedgehog_dot_protocol_dot_proto_dot_motor__pb2._MOTORSTATEMESSAGE
_HEDGEHOGMESSAGE.fields_by_name['motor_set_position_action'].message_type = hedgehog_dot_protocol_dot_proto_dot_motor__pb2._MOTORSETPOSITIONACTION
_HEDGEHOGMESSAGE.fields_by_name['servo_action'].message_type = hedgehog_dot_protocol_dot_proto_dot_servo__pb2._SERVOACTION
_HEDGEHOGMESSAGE.fields_by_name['servo_command_message'].message_type = hedgehog_dot_protocol_dot_proto_dot_servo__pb2._SERVOCOMMANDMESSAGE
_HEDGEHOGMESSAGE.fields_by_name['process_execute_action'].message_type = hedgehog_dot_protocol_dot_proto_dot_process__pb2._PROCESSEXECUTEACTION
_HEDGEHOGMESSAGE.fields_by_name['process_execute_reply'].message_type = hedgehog_dot_protocol_dot_proto_dot_process__pb2._PROCESSEXECUTEREPLY
_HEDGEHOGMESSAGE.fields_by_name['process_stream_message'].message_type = hedgehog_dot_protocol_dot_proto_dot_process__pb2._PROCESSSTREAMMESSAGE
_HEDGEHOGMESSAGE.fields_by_name['process_signal_action'].message_type = hedgehog_dot_protocol_dot_proto_dot_process__pb2._PROCESSSIGNALACTION
_HEDGEHOGMESSAGE.fields_by_name['process_exit_update'].message_type = hedgehog_dot_protocol_dot_proto_dot_process__pb2._PROCESSEXITUPDATE
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['acknowledgement'])
_HEDGEHOGMESSAGE.fields_by_name['acknowledgement'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['io_action'])
_HEDGEHOGMESSAGE.fields_by_name['io_action'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['io_command_message'])
_HEDGEHOGMESSAGE.fields_by_name['io_command_message'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['analog_message'])
_HEDGEHOGMESSAGE.fields_by_name['analog_message'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['digital_message'])
_HEDGEHOGMESSAGE.fields_by_name['digital_message'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['motor_action'])
_HEDGEHOGMESSAGE.fields_by_name['motor_action'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['motor_command_message'])
_HEDGEHOGMESSAGE.fields_by_name['motor_command_message'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['motor_state_message'])
_HEDGEHOGMESSAGE.fields_by_name['motor_state_message'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['motor_set_position_action'])
_HEDGEHOGMESSAGE.fields_by_name['motor_set_position_action'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['servo_action'])
_HEDGEHOGMESSAGE.fields_by_name['servo_action'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['servo_command_message'])
_HEDGEHOGMESSAGE.fields_by_name['servo_command_message'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['process_execute_action'])
_HEDGEHOGMESSAGE.fields_by_name['process_execute_action'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['process_execute_reply'])
_HEDGEHOGMESSAGE.fields_by_name['process_execute_reply'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['process_stream_message'])
_HEDGEHOGMESSAGE.fields_by_name['process_stream_message'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['process_signal_action'])
_HEDGEHOGMESSAGE.fields_by_name['process_signal_action'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
_HEDGEHOGMESSAGE.oneofs_by_name['payload'].fields.append(
  _HEDGEHOGMESSAGE.fields_by_name['process_exit_update'])
_HEDGEHOGMESSAGE.fields_by_name['process_exit_update'].containing_oneof = _HEDGEHOGMESSAGE.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['HedgehogMessage'] = _HEDGEHOGMESSAGE

HedgehogMessage = _reflection.GeneratedProtocolMessageType('HedgehogMessage', (_message.Message,), dict(
  DESCRIPTOR = _HEDGEHOGMESSAGE,
  __module__ = 'hedgehog.protocol.proto.hedgehog_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.HedgehogMessage)
  ))
_sym_db.RegisterMessage(HedgehogMessage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\037at.pria.hedgehog.protocol.protoB\tHedgehogP'))
# @@protoc_insertion_point(module_scope)
