# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hedgehog/protocol/proto/process.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hedgehog/protocol/proto/process.proto',
  package='hedgehog.protocol.proto',
  syntax='proto3',
  serialized_pb=_b('\n%hedgehog/protocol/proto/process.proto\x12\x17hedgehog.protocol.proto\"9\n\x14ProcessExecuteAction\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x13\n\x0bworking_dir\x18\x01 \x01(\t\"\"\n\x13ProcessExecuteReply\x12\x0b\n\x03pid\x18\x01 \x01(\r\"j\n\x14ProcessStreamMessage\x12\x0b\n\x03pid\x18\x01 \x01(\r\x12\x36\n\x06\x66ileno\x18\x02 \x01(\x0e\x32&.hedgehog.protocol.proto.ProcessFileno\x12\r\n\x05\x63hunk\x18\x03 \x01(\x0c\"2\n\x13ProcessSignalAction\x12\x0b\n\x03pid\x18\x01 \x01(\r\x12\x0e\n\x06signal\x18\x02 \x01(\r\"3\n\x11ProcessExitUpdate\x12\x0b\n\x03pid\x18\x01 \x01(\r\x12\x11\n\texit_code\x18\x02 \x01(\x05*2\n\rProcessFileno\x12\t\n\x05STDIN\x10\x00\x12\n\n\x06STDOUT\x10\x01\x12\n\n\x06STDERR\x10\x02\x42+\n\x1f\x61t.pria.hedgehog.protocol.protoB\x08ProcessPb\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_PROCESSFILENO = _descriptor.EnumDescriptor(
  name='ProcessFileno',
  full_name='hedgehog.protocol.proto.ProcessFileno',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STDIN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STDOUT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STDERR', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=374,
  serialized_end=424,
)
_sym_db.RegisterEnumDescriptor(_PROCESSFILENO)

ProcessFileno = enum_type_wrapper.EnumTypeWrapper(_PROCESSFILENO)
STDIN = 0
STDOUT = 1
STDERR = 2



_PROCESSEXECUTEACTION = _descriptor.Descriptor(
  name='ProcessExecuteAction',
  full_name='hedgehog.protocol.proto.ProcessExecuteAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='args', full_name='hedgehog.protocol.proto.ProcessExecuteAction.args', index=0,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='working_dir', full_name='hedgehog.protocol.proto.ProcessExecuteAction.working_dir', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=123,
)


_PROCESSEXECUTEREPLY = _descriptor.Descriptor(
  name='ProcessExecuteReply',
  full_name='hedgehog.protocol.proto.ProcessExecuteReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='hedgehog.protocol.proto.ProcessExecuteReply.pid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=159,
)


_PROCESSSTREAMMESSAGE = _descriptor.Descriptor(
  name='ProcessStreamMessage',
  full_name='hedgehog.protocol.proto.ProcessStreamMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='hedgehog.protocol.proto.ProcessStreamMessage.pid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fileno', full_name='hedgehog.protocol.proto.ProcessStreamMessage.fileno', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='chunk', full_name='hedgehog.protocol.proto.ProcessStreamMessage.chunk', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=267,
)


_PROCESSSIGNALACTION = _descriptor.Descriptor(
  name='ProcessSignalAction',
  full_name='hedgehog.protocol.proto.ProcessSignalAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='hedgehog.protocol.proto.ProcessSignalAction.pid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signal', full_name='hedgehog.protocol.proto.ProcessSignalAction.signal', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=319,
)


_PROCESSEXITUPDATE = _descriptor.Descriptor(
  name='ProcessExitUpdate',
  full_name='hedgehog.protocol.proto.ProcessExitUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='hedgehog.protocol.proto.ProcessExitUpdate.pid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='hedgehog.protocol.proto.ProcessExitUpdate.exit_code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=372,
)

_PROCESSSTREAMMESSAGE.fields_by_name['fileno'].enum_type = _PROCESSFILENO
DESCRIPTOR.message_types_by_name['ProcessExecuteAction'] = _PROCESSEXECUTEACTION
DESCRIPTOR.message_types_by_name['ProcessExecuteReply'] = _PROCESSEXECUTEREPLY
DESCRIPTOR.message_types_by_name['ProcessStreamMessage'] = _PROCESSSTREAMMESSAGE
DESCRIPTOR.message_types_by_name['ProcessSignalAction'] = _PROCESSSIGNALACTION
DESCRIPTOR.message_types_by_name['ProcessExitUpdate'] = _PROCESSEXITUPDATE
DESCRIPTOR.enum_types_by_name['ProcessFileno'] = _PROCESSFILENO

ProcessExecuteAction = _reflection.GeneratedProtocolMessageType('ProcessExecuteAction', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSEXECUTEACTION,
  __module__ = 'hedgehog.protocol.proto.process_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.ProcessExecuteAction)
  ))
_sym_db.RegisterMessage(ProcessExecuteAction)

ProcessExecuteReply = _reflection.GeneratedProtocolMessageType('ProcessExecuteReply', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSEXECUTEREPLY,
  __module__ = 'hedgehog.protocol.proto.process_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.ProcessExecuteReply)
  ))
_sym_db.RegisterMessage(ProcessExecuteReply)

ProcessStreamMessage = _reflection.GeneratedProtocolMessageType('ProcessStreamMessage', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSSTREAMMESSAGE,
  __module__ = 'hedgehog.protocol.proto.process_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.ProcessStreamMessage)
  ))
_sym_db.RegisterMessage(ProcessStreamMessage)

ProcessSignalAction = _reflection.GeneratedProtocolMessageType('ProcessSignalAction', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSSIGNALACTION,
  __module__ = 'hedgehog.protocol.proto.process_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.ProcessSignalAction)
  ))
_sym_db.RegisterMessage(ProcessSignalAction)

ProcessExitUpdate = _reflection.GeneratedProtocolMessageType('ProcessExitUpdate', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSEXITUPDATE,
  __module__ = 'hedgehog.protocol.proto.process_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.ProcessExitUpdate)
  ))
_sym_db.RegisterMessage(ProcessExitUpdate)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\037at.pria.hedgehog.protocol.protoB\010ProcessP'))
# @@protoc_insertion_point(module_scope)
