# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hedgehog/protocol/proto/digital.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hedgehog/protocol/proto/digital.proto',
  package='hedgehog.protocol.proto',
  syntax='proto3',
  serialized_pb=_b('\n%hedgehog/protocol/proto/digital.proto\x12\x17hedgehog.protocol.proto\"\x1e\n\x0e\x44igitalRequest\x12\x0c\n\x04port\x18\x01 \x01(\r\",\n\rDigitalUpdate\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x08\"B\n\x12\x44igitalStateAction\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x0e\n\x06pullup\x18\x02 \x01(\x08\x12\x0e\n\x06output\x18\x03 \x01(\x08\",\n\rDigitalAction\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\r\n\x05level\x18\x02 \x01(\x08\x62\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_DIGITALREQUEST = _descriptor.Descriptor(
  name='DigitalRequest',
  full_name='hedgehog.protocol.proto.DigitalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.DigitalRequest.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=96,
)


_DIGITALUPDATE = _descriptor.Descriptor(
  name='DigitalUpdate',
  full_name='hedgehog.protocol.proto.DigitalUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.DigitalUpdate.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='hedgehog.protocol.proto.DigitalUpdate.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=142,
)


_DIGITALSTATEACTION = _descriptor.Descriptor(
  name='DigitalStateAction',
  full_name='hedgehog.protocol.proto.DigitalStateAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.DigitalStateAction.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pullup', full_name='hedgehog.protocol.proto.DigitalStateAction.pullup', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='output', full_name='hedgehog.protocol.proto.DigitalStateAction.output', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=210,
)


_DIGITALACTION = _descriptor.Descriptor(
  name='DigitalAction',
  full_name='hedgehog.protocol.proto.DigitalAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.DigitalAction.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='hedgehog.protocol.proto.DigitalAction.level', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=212,
  serialized_end=256,
)

DESCRIPTOR.message_types_by_name['DigitalRequest'] = _DIGITALREQUEST
DESCRIPTOR.message_types_by_name['DigitalUpdate'] = _DIGITALUPDATE
DESCRIPTOR.message_types_by_name['DigitalStateAction'] = _DIGITALSTATEACTION
DESCRIPTOR.message_types_by_name['DigitalAction'] = _DIGITALACTION

DigitalRequest = _reflection.GeneratedProtocolMessageType('DigitalRequest', (_message.Message,), dict(
  DESCRIPTOR = _DIGITALREQUEST,
  __module__ = 'hedgehog.protocol.proto.digital_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.DigitalRequest)
  ))
_sym_db.RegisterMessage(DigitalRequest)

DigitalUpdate = _reflection.GeneratedProtocolMessageType('DigitalUpdate', (_message.Message,), dict(
  DESCRIPTOR = _DIGITALUPDATE,
  __module__ = 'hedgehog.protocol.proto.digital_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.DigitalUpdate)
  ))
_sym_db.RegisterMessage(DigitalUpdate)

DigitalStateAction = _reflection.GeneratedProtocolMessageType('DigitalStateAction', (_message.Message,), dict(
  DESCRIPTOR = _DIGITALSTATEACTION,
  __module__ = 'hedgehog.protocol.proto.digital_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.DigitalStateAction)
  ))
_sym_db.RegisterMessage(DigitalStateAction)

DigitalAction = _reflection.GeneratedProtocolMessageType('DigitalAction', (_message.Message,), dict(
  DESCRIPTOR = _DIGITALACTION,
  __module__ = 'hedgehog.protocol.proto.digital_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.DigitalAction)
  ))
_sym_db.RegisterMessage(DigitalAction)


# @@protoc_insertion_point(module_scope)
