# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hedgehog/protocol/proto/ack.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hedgehog/protocol/proto/ack.proto',
  package='hedgehog.protocol.proto',
  syntax='proto3',
  serialized_pb=_b('\n!hedgehog/protocol/proto/ack.proto\x12\x17hedgehog.protocol.proto\"^\n\x0f\x41\x63knowledgement\x12:\n\x04\x63ode\x18\x01 \x01(\x0e\x32,.hedgehog.protocol.proto.AcknowledgementCode\x12\x0f\n\x07message\x18\x02 \x01(\t*t\n\x13\x41\x63knowledgementCode\x12\x06\n\x02OK\x10\x00\x12\x13\n\x0fUNKNOWN_COMMAND\x10\x01\x12\x13\n\x0fINVALID_COMMAND\x10\x02\x12\x17\n\x13UNSUPPORTED_COMMAND\x10\x03\x12\x12\n\x0e\x46\x41ILED_COMMAND\x10\x04\x42\'\n\x1f\x61t.pria.hedgehog.protocol.protoB\x04\x41\x63kPb\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_ACKNOWLEDGEMENTCODE = _descriptor.EnumDescriptor(
  name='AcknowledgementCode',
  full_name='hedgehog.protocol.proto.AcknowledgementCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_COMMAND', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_COMMAND', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_COMMAND', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_COMMAND', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=158,
  serialized_end=274,
)
_sym_db.RegisterEnumDescriptor(_ACKNOWLEDGEMENTCODE)

AcknowledgementCode = enum_type_wrapper.EnumTypeWrapper(_ACKNOWLEDGEMENTCODE)
OK = 0
UNKNOWN_COMMAND = 1
INVALID_COMMAND = 2
UNSUPPORTED_COMMAND = 3
FAILED_COMMAND = 4



_ACKNOWLEDGEMENT = _descriptor.Descriptor(
  name='Acknowledgement',
  full_name='hedgehog.protocol.proto.Acknowledgement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='hedgehog.protocol.proto.Acknowledgement.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='hedgehog.protocol.proto.Acknowledgement.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=156,
)

_ACKNOWLEDGEMENT.fields_by_name['code'].enum_type = _ACKNOWLEDGEMENTCODE
DESCRIPTOR.message_types_by_name['Acknowledgement'] = _ACKNOWLEDGEMENT
DESCRIPTOR.enum_types_by_name['AcknowledgementCode'] = _ACKNOWLEDGEMENTCODE

Acknowledgement = _reflection.GeneratedProtocolMessageType('Acknowledgement', (_message.Message,), dict(
  DESCRIPTOR = _ACKNOWLEDGEMENT,
  __module__ = 'hedgehog.protocol.proto.ack_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.Acknowledgement)
  ))
_sym_db.RegisterMessage(Acknowledgement)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\037at.pria.hedgehog.protocol.protoB\004AckP'))
# @@protoc_insertion_point(module_scope)
