# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hedgehog/protocol/proto/io.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hedgehog.protocol.proto import subscription_pb2 as hedgehog_dot_protocol_dot_proto_dot_subscription__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hedgehog/protocol/proto/io.proto',
  package='hedgehog.protocol.proto',
  syntax='proto3',
  serialized_pb=_b('\n hedgehog/protocol/proto/io.proto\x12\x17hedgehog.protocol.proto\x1a*hedgehog/protocol/proto/subscription.proto\"I\n\x08IOAction\x12\x0c\n\x04port\x18\x01 \x01(\r\x12/\n\x05\x66lags\x18\x02 \x01(\x0e\x32 .hedgehog.protocol.proto.IOFlags\"\x8e\x01\n\x10IOCommandMessage\x12\x0c\n\x04port\x18\x01 \x01(\r\x12/\n\x05\x66lags\x18\x02 \x01(\x0e\x32 .hedgehog.protocol.proto.IOFlags\x12;\n\x0csubscription\x18\x03 \x01(\x0b\x32%.hedgehog.protocol.proto.Subscription\"i\n\rAnalogMessage\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\x12;\n\x0csubscription\x18\x03 \x01(\x0b\x32%.hedgehog.protocol.proto.Subscription\"j\n\x0e\x44igitalMessage\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x08\x12;\n\x0csubscription\x18\x03 \x01(\x0b\x32%.hedgehog.protocol.proto.Subscription*\x97\x01\n\x07IOFlags\x12\x12\n\x0eINPUT_FLOATING\x10\x00\x12\x10\n\x0cINPUT_PULLUP\x10\x02\x12\x12\n\x0eINPUT_PULLDOWN\x10\x04\x12\x0e\n\nOUTPUT_OFF\x10\x01\x12\r\n\tOUTPUT_ON\x10\t\x12\n\n\x06OUTPUT\x10\x01\x12\n\n\x06PULLUP\x10\x02\x12\x0c\n\x08PULLDOWN\x10\x04\x12\t\n\x05LEVEL\x10\x08\x1a\x02\x10\x01\x42&\n\x1f\x61t.pria.hedgehog.protocol.protoB\x03IOPb\x06proto3')
  ,
  dependencies=[hedgehog_dot_protocol_dot_proto_dot_subscription__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_IOFLAGS = _descriptor.EnumDescriptor(
  name='IOFlags',
  full_name='hedgehog.protocol.proto.IOFlags',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INPUT_FLOATING', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_PULLUP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_PULLDOWN', index=2, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_OFF', index=3, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT_ON', index=4, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUTPUT', index=5, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PULLUP', index=6, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PULLDOWN', index=7, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=_descriptor._ParseOptions(descriptor_pb2.EnumOptions(), _b('\020\001')),
  serialized_start=541,
  serialized_end=692,
)
_sym_db.RegisterEnumDescriptor(_IOFLAGS)

IOFlags = enum_type_wrapper.EnumTypeWrapper(_IOFLAGS)
INPUT_FLOATING = 0
INPUT_PULLUP = 2
INPUT_PULLDOWN = 4
OUTPUT_OFF = 1
OUTPUT_ON = 9
OUTPUT = 1
PULLUP = 2
PULLDOWN = 4
LEVEL = 8



_IOACTION = _descriptor.Descriptor(
  name='IOAction',
  full_name='hedgehog.protocol.proto.IOAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.IOAction.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='hedgehog.protocol.proto.IOAction.flags', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=178,
)


_IOCOMMANDMESSAGE = _descriptor.Descriptor(
  name='IOCommandMessage',
  full_name='hedgehog.protocol.proto.IOCommandMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.IOCommandMessage.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='hedgehog.protocol.proto.IOCommandMessage.flags', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subscription', full_name='hedgehog.protocol.proto.IOCommandMessage.subscription', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=323,
)


_ANALOGMESSAGE = _descriptor.Descriptor(
  name='AnalogMessage',
  full_name='hedgehog.protocol.proto.AnalogMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.AnalogMessage.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='hedgehog.protocol.proto.AnalogMessage.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subscription', full_name='hedgehog.protocol.proto.AnalogMessage.subscription', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=430,
)


_DIGITALMESSAGE = _descriptor.Descriptor(
  name='DigitalMessage',
  full_name='hedgehog.protocol.proto.DigitalMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.DigitalMessage.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='hedgehog.protocol.proto.DigitalMessage.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subscription', full_name='hedgehog.protocol.proto.DigitalMessage.subscription', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=538,
)

_IOACTION.fields_by_name['flags'].enum_type = _IOFLAGS
_IOCOMMANDMESSAGE.fields_by_name['flags'].enum_type = _IOFLAGS
_IOCOMMANDMESSAGE.fields_by_name['subscription'].message_type = hedgehog_dot_protocol_dot_proto_dot_subscription__pb2._SUBSCRIPTION
_ANALOGMESSAGE.fields_by_name['subscription'].message_type = hedgehog_dot_protocol_dot_proto_dot_subscription__pb2._SUBSCRIPTION
_DIGITALMESSAGE.fields_by_name['subscription'].message_type = hedgehog_dot_protocol_dot_proto_dot_subscription__pb2._SUBSCRIPTION
DESCRIPTOR.message_types_by_name['IOAction'] = _IOACTION
DESCRIPTOR.message_types_by_name['IOCommandMessage'] = _IOCOMMANDMESSAGE
DESCRIPTOR.message_types_by_name['AnalogMessage'] = _ANALOGMESSAGE
DESCRIPTOR.message_types_by_name['DigitalMessage'] = _DIGITALMESSAGE
DESCRIPTOR.enum_types_by_name['IOFlags'] = _IOFLAGS

IOAction = _reflection.GeneratedProtocolMessageType('IOAction', (_message.Message,), dict(
  DESCRIPTOR = _IOACTION,
  __module__ = 'hedgehog.protocol.proto.io_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.IOAction)
  ))
_sym_db.RegisterMessage(IOAction)

IOCommandMessage = _reflection.GeneratedProtocolMessageType('IOCommandMessage', (_message.Message,), dict(
  DESCRIPTOR = _IOCOMMANDMESSAGE,
  __module__ = 'hedgehog.protocol.proto.io_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.IOCommandMessage)
  ))
_sym_db.RegisterMessage(IOCommandMessage)

AnalogMessage = _reflection.GeneratedProtocolMessageType('AnalogMessage', (_message.Message,), dict(
  DESCRIPTOR = _ANALOGMESSAGE,
  __module__ = 'hedgehog.protocol.proto.io_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.AnalogMessage)
  ))
_sym_db.RegisterMessage(AnalogMessage)

DigitalMessage = _reflection.GeneratedProtocolMessageType('DigitalMessage', (_message.Message,), dict(
  DESCRIPTOR = _DIGITALMESSAGE,
  __module__ = 'hedgehog.protocol.proto.io_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.DigitalMessage)
  ))
_sym_db.RegisterMessage(DigitalMessage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\037at.pria.hedgehog.protocol.protoB\003IOP'))
_IOFLAGS.has_options = True
_IOFLAGS._options = _descriptor._ParseOptions(descriptor_pb2.EnumOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)
